
# Slot: activity set




URI: [core:activity_set](https://w3id.org/linkml/tests/core/activity_set)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Activity](Activity.md)

## Parents


## Children


## Used by

